==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebListItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListItemDescription } from "./WebListItemDescription";
/**
 * @hidden
 */
var WebListItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebListItemDescriptionMetadata, _super);
    function WebListItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListItemDescriptionMetadata.b = function (a) {
        if (WebListItemDescriptionMetadata.a == null) {
            WebListItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListItemDescriptionMetadata.c(WebListItemDescriptionMetadata.a);
        }
        if (a.k(WebListItemDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebListItemDescriptionMetadata.a);
    };
    WebListItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ListItem");
        a.item("__tagNameWC", "String:igc-list-item");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
    };
    WebListItemDescriptionMetadata.d = function (a) {
        WebListItemDescriptionMetadata.b(a);
        a.ac("WebListItem", function () { return new WebListItemDescription(); });
        a.ab("WebListItem", WebListItemDescriptionMetadata.a);
    };
    WebListItemDescriptionMetadata.$t = markType(WebListItemDescriptionMetadata, 'WebListItemDescriptionMetadata');
    WebListItemDescriptionMetadata.a = null;
    return WebListItemDescriptionMetadata;
}(Base));
export { WebListItemDescriptionMetadata };

==> igniteui-webcomponents-core-5.4.1.tgz: package/esm5/lib/WebListItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListItemDescription } from "./WebListItemDescription";
/**
 * @hidden
 */
var WebListItemDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebListItemDescriptionMetadata, _super);
    function WebListItemDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebListItemDescriptionMetadata.b = function (a) {
        if (WebListItemDescriptionMetadata.a == null) {
            WebListItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebListItemDescriptionMetadata.c(WebListItemDescriptionMetadata.a);
        }
        if (a.k(WebListItemDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebListItemDescriptionMetadata.a);
    };
    WebListItemDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:ListItem");
        a.item("__tagNameWC", "String:igc-list-item");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("Selected", "Boolean");
    };
    WebListItemDescriptionMetadata.d = function (a) {
        WebListItemDescriptionMetadata.b(a);
        a.ae("WebListItem", function () { return new WebListItemDescription(); });
        a.ad("WebListItem", WebListItemDescriptionMetadata.a);
    };
    WebListItemDescriptionMetadata.$t = markType(WebListItemDescriptionMetadata, 'WebListItemDescriptionMetadata');
    WebListItemDescriptionMetadata.a = null;
    return WebListItemDescriptionMetadata;
}(Base));
export { WebListItemDescriptionMetadata };
